#[unsafe(no_mangle)]pub unsafe extern "C" fn diplomat_alloc(
size: usize,
align: usize,
) -> *mut u8Expand description
Allocates a buffer of a given size in Rust’s memory.
Primarily to be called by generated FFI bindings, not Rust code, but is available if needed.
Safety
- The allocated buffer must be freed with
diplomat_free().