pub type DiplomatOwnedStr16Slice<'a> = DiplomatOwnedSlice<u16>;Expand description
An unvalidated, owned UTF-16 string that is safe to use over FFI
This type will usually map to some string type in the target language, and you will not need to worry about the safety of mismatched string invariants.
Aliased Type
#[repr(C)]pub struct DiplomatOwnedStr16Slice<'a> {
ptr: *mut u16,
len: usize,
phantom: PhantomData<Box<[u16]>>,
}Fields
ptr: *mut u16len: usizephantom: PhantomData<Box<[u16]>>