pub type DiplomatOwnedStrSlice = DiplomatOwnedSlice<u8>;Expand description
This like Box<str>, but unvalidated and safe to use over FFI
This type will usually map to some string type in the target language, and you will not need to worry about the safety of mismatched string invariants.
Aliased Type
#[repr(C)]pub struct DiplomatOwnedStrSlice {
ptr: *mut u8,
len: usize,
phantom: PhantomData<Box<[u8]>>,
}Fields
ptr: *mut u8len: usizephantom: PhantomData<Box<[u8]>>