DiplomatStr

Type Alias DiplomatStr 

pub type DiplomatStr = [u8];
Like str, but unvalidated.

This is a dynamically sized type, it should be used behind an & or a Box<T>

This type will usually map to some string type in the target language, and you will not need to worry about the safety of mismatched string invariants.