DiplomatStr16

Type Alias DiplomatStr16 

pub type DiplomatStr16 = [u16];
Like Wstr, but unvalidated.

This is a dynamically sized type, it should be used behind an & or a Box<T>

This type will usually map to some string type in the target language, and you will not need to worry about the safety of mismatched string invariants.