pub type DiplomatChar = u32;
Like char, but unvalidated.
char
This type will usually map to some character type in the target language, and you will not need to worry about the safety of mismatched string invariants.